from enum import Enum

class Glass(Enum):
    COCKTAIL = "Cocktail glass"
    HIGHBALL = "Highball glass"
    OLD_FASHIONED = "Old-fashioned glass"
    WHISKEY = "Whiskey Glass"
    COLLINS = "Collins Glass"
    POUSSE_CAFE = "Pousse cafe glass"
    CHAMPAGNE_FLUTE = "Champagne flute"
    WHISKEY_SOUR = "Whiskey sour glass"
    CORDIAL = "Cordial glass"
    BRANDY_SNIFTER = "Brandy snifter"
    WHITE_WHINE = "White wine glass"
    NICK_AND_NORA = "Nick and Nora Glass"
    HURRICANE = "Hurricane glass"
    COFFEE_NUM  = "Coffee mug"
    SHOT_GLASS = "Shot glass"
    JAR = "Jar" 
    IRISH_COFFEE_CUP = "Irish coffee cup"
    PUNCH_BOWL = "Punch bowl"
    PITCHER = "Pitcher"
    PINT =  "Pint glass"
    COPPER_MUG = "Copper Mug"
    WINE = "Wine Glass"
    BEER_MUG = "Beer mug"
    COUPETTE = "Margarita/Coupette glass"
    MARGARITA = "Margarita glass"
    BEER_PILSNER = "Beer pilsner"
    BEER = "Beer Glass"
    PARFAIT = "Parfait glass"
    MASON = "Mason jar"
    MARTINI = "Martini Glass"
    BALLOON = "Balloon Glass"
    COUPE = "Coupe Glass"

class Category(Enum):
    ORDINARY_DRINK = "Ordinary Drink"
    COCKTAIL = "Cocktail"
    SHAKE = "Shake"
    OTHER_UNKNOWN = "Other / Unknown"
    COCOA = "Cocoa"
    SHOT =  "Shot"
    COFFEE_TEA = "Coffee / Tea"
    HOMEMADE_LIQUER = "Homemade Liqueur"
    PUNCH_PARTY ="Punch / Party Drink"
    BEER = "Beer"
    SOFT_DRINK = "Soft Drink"


class Ingredient(Enum):
    APPLEJACK = "Applejack"
    LIGHT_RUM = "Light rum"
    GIN = "Gin"
    DARK_RUM = "Dark rum"
    SWEET_VERMOUTH = "Sweet Vermouth"
    STRAWBERRY_SCHNAPPS = "Strawberry schnapps"
    SCOTCH = "Scotch"
    APRICOT_BRANDY = "Apricot brandy"
    TRIPLE_SEC = "Triple sec"
    SOUTHERN_COMFORT = "Southern Comfort"
    ORANGE_BITTERS = "Orange bitters"
    BRANDY = "Brandy"
    LEMON_VODKA = "Lemon vodka"
    BLENDED_WHISKEY = "Blended whiskey"
    DRY_VERMOUTH = "Dry Vermouth"
    AMARETTO= "Amaretto"
    TEA = "Tea"
    CHAMPAGNE = "Champagne"
    COFFEE_LIQUEUR = "Coffee liqueur"
    BOURBON = "Bourbon"
    TEQUILA = "Tequila"
    VODKA = "Vodka"
    ANEJO_RUM = "Añejo rum"
    BITTERS = "Bitters"
    SUGAR = "Sugar"
    KAHLUA = "Kahlua"
    DEMERARA_SUGAR = "demerara Sugar"
    DUBONNET_ROUGE = "Dubonnet Rouge"
    WATERMELON = "Watermelon"
    LIME_JUICE = "Lime juice"
    IRISH_WHISKEY= "Irish whiskey"
    APPLE_BRANDY = "Apple brandy"
    CARBONATED_WATER = "Carbonated water"
    CHERRY_BRANDY = "Cherry brandy"
    CREME_DE_CACAO = "Creme de Cacao"
    GRENADINE = "Grenadine"
    PORT = "Port"
    COFFEE_BRANDY = "Coffee brandy"
    RED_WINE = "Red wine"
    RUM = "Rum"
    GRAPEFRUIT_JUICE = "Grapefruit juice"
    RICARD = "Ricard"
    SHERRY = "Sherry"
    COGNAC = "Cognac"
    SLOE_GIN = "Sloe gin"
    APPLE_JUICE = "Apple juice"
    PINEAPPLE_JUICE = "Pineapple juice"
    LEMON_JUICE = "Lemon juice"
    SUGAR_SYRUP = "Sugar syrup"
    MILK = "Milk"